
From: Jeff Dike <jdike@addtoit.com>

Some small cleanups that resulted from the x86_64 merge:
	Some unneeded includes were removed
	Some overlong lines were shortened
	current_thread_info was replaced by a generic version.
	Some warnings were fixed

Signed-off-by: Jeff Dike <jdike@addtoit.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/um/include/process.h          |    2 +-
 25-akpm/arch/um/kernel/mem.c               |    2 ++
 25-akpm/arch/um/kernel/mem_user.c          |    4 +---
 25-akpm/arch/um/kernel/process.c           |    7 ++-----
 25-akpm/arch/um/kernel/skas/process.c      |    3 ++-
 25-akpm/arch/um/kernel/skas/trap_user.c    |    1 -
 25-akpm/arch/um/kernel/tt/ptproxy/sysdep.c |    1 -
 25-akpm/arch/um/kernel/tt/ptproxy/wait.c   |    1 -
 25-akpm/arch/um/kernel/tt/trap_user.c      |    1 -
 25-akpm/arch/um/kernel/um_arch.c           |    5 +++++
 25-akpm/arch/um/os-Linux/Makefile          |    2 ++
 25-akpm/arch/um/os-Linux/elf_aux.c         |    1 -
 25-akpm/arch/um/os-Linux/user_syms.c       |    8 +++++---
 25-akpm/include/asm-um/processor-i386.h    |    3 ++-
 25-akpm/include/asm-um/thread_info.h       |    2 +-
 15 files changed, 23 insertions(+), 20 deletions(-)

diff -puN arch/um/include/process.h~uml-code-tidying arch/um/include/process.h
--- 25/arch/um/include/process.h~uml-code-tidying	2005-01-09 23:44:15.114865680 -0800
+++ 25-akpm/arch/um/include/process.h	2005-01-09 23:44:15.136862336 -0800
@@ -6,7 +6,7 @@
 #ifndef __PROCESS_H__
 #define __PROCESS_H__
 
-#include <asm/sigcontext.h>
+#include <signal.h>
 
 extern void sig_handler(int sig, struct sigcontext sc);
 extern void alarm_handler(int sig, struct sigcontext sc);
diff -puN arch/um/kernel/mem.c~uml-code-tidying arch/um/kernel/mem.c
--- 25/arch/um/kernel/mem.c~uml-code-tidying	2005-01-09 23:44:15.115865528 -0800
+++ 25-akpm/arch/um/kernel/mem.c	2005-01-09 23:44:15.137862184 -0800
@@ -173,6 +173,7 @@ static void init_highmem(void)
 
 static void __init fixaddr_user_init( void)
 {
+#if FIXADDR_USER_START != 0
 	long size = FIXADDR_USER_END - FIXADDR_USER_START;
 	pgd_t *pgd;
 	pmd_t *pmd;
@@ -192,6 +193,7 @@ static void __init fixaddr_user_init( vo
 		pte = pte_offset_kernel(pmd, vaddr);
 		pte_set_val( (*pte), paddr, PAGE_READONLY);
 	}
+#endif
 }
 
 void paging_init(void)
diff -puN arch/um/kernel/mem_user.c~uml-code-tidying arch/um/kernel/mem_user.c
--- 25/arch/um/kernel/mem_user.c~uml-code-tidying	2005-01-09 23:44:15.117865224 -0800
+++ 25-akpm/arch/um/kernel/mem_user.c	2005-01-09 23:44:15.137862184 -0800
@@ -48,8 +48,6 @@
 #include "tempfile.h"
 #include "kern_constants.h"
 
-extern struct mem_region physmem_region;
-
 #define TEMPNAME_TEMPLATE "vm_file-XXXXXX"
 
 static int create_tmp_file(unsigned long len)
@@ -135,7 +133,7 @@ static int create_anon_file(unsigned lon
 
 	addr = mmap(NULL, len, PROT_READ | PROT_WRITE, MAP_PRIVATE, fd, 0);
 	if(addr == MAP_FAILED){
-		os_print_error((int) addr, "mapping physmem file");
+		perror("mapping physmem file");
 		exit(1);
 	}
 	munmap(addr, len);
diff -puN arch/um/kernel/process.c~uml-code-tidying arch/um/kernel/process.c
--- 25/arch/um/kernel/process.c~uml-code-tidying	2005-01-09 23:44:15.118865072 -0800
+++ 25-akpm/arch/um/kernel/process.c	2005-01-09 23:44:15.138862032 -0800
@@ -13,14 +13,10 @@
 #include <setjmp.h>
 #include <sys/time.h>
 #include <sys/ptrace.h>
-#include <linux/ptrace.h>
 #include <sys/wait.h>
 #include <sys/mman.h>
-#include <asm/ptrace.h>
-#include <asm/sigcontext.h>
 #include <asm/unistd.h>
 #include <asm/page.h>
-#include <asm/user.h>
 #include "user_util.h"
 #include "kern_util.h"
 #include "user.h"
@@ -28,6 +24,7 @@
 #include "signal_kern.h"
 #include "signal_user.h"
 #include "sysdep/ptrace.h"
+#include "sysdep/ptrace_user.h"
 #include "sysdep/sigcontext.h"
 #include "irq_user.h"
 #include "ptrace_user.h"
@@ -331,7 +328,7 @@ void __init check_ptrace(void)
 		CATCH_EINTR(n = waitpid(pid, &status, WUNTRACED));
 		if(n < 0)
 			panic("check_ptrace : wait failed, errno = %d", errno);
-		if(!WIFSTOPPED(status) || (WSTOPSIG(status) != (SIGTRAP + 0x80)))
+		if(!WIFSTOPPED(status) || (WSTOPSIG(status) != SIGTRAP + 0x80))
 			panic("check_ptrace : expected SIGTRAP + 0x80, "
 			      "got status = %d", status);
 		
diff -puN arch/um/kernel/skas/process.c~uml-code-tidying arch/um/kernel/skas/process.c
--- 25/arch/um/kernel/skas/process.c~uml-code-tidying	2005-01-09 23:44:15.120864768 -0800
+++ 25-akpm/arch/um/kernel/skas/process.c	2005-01-09 23:44:15.138862032 -0800
@@ -73,7 +73,8 @@ static void handle_trap(int pid, union u
 			      "errno = %d\n", errno);
 
 		CATCH_EINTR(err = waitpid(pid, &status, WUNTRACED));
-		if((err < 0) || !WIFSTOPPED(status) || (WSTOPSIG(status) != (SIGTRAP + 0x80)))
+		if((err < 0) || !WIFSTOPPED(status) ||
+		   (WSTOPSIG(status) != SIGTRAP + 0x80))
 			panic("handle_trap - failed to wait at end of syscall, "
 			      "errno = %d, status = %d\n", errno, status);
 	}
diff -puN arch/um/kernel/skas/trap_user.c~uml-code-tidying arch/um/kernel/skas/trap_user.c
--- 25/arch/um/kernel/skas/trap_user.c~uml-code-tidying	2005-01-09 23:44:15.121864616 -0800
+++ 25-akpm/arch/um/kernel/skas/trap_user.c	2005-01-09 23:44:15.139861880 -0800
@@ -5,7 +5,6 @@
 
 #include <signal.h>
 #include <errno.h>
-#include <asm/sigcontext.h>
 #include "sysdep/ptrace.h"
 #include "signal_user.h"
 #include "user_util.h"
diff -puN arch/um/kernel/tt/ptproxy/sysdep.c~uml-code-tidying arch/um/kernel/tt/ptproxy/sysdep.c
--- 25/arch/um/kernel/tt/ptproxy/sysdep.c~uml-code-tidying	2005-01-09 23:44:15.123864312 -0800
+++ 25-akpm/arch/um/kernel/tt/ptproxy/sysdep.c	2005-01-09 23:44:15.139861880 -0800
@@ -12,7 +12,6 @@ terms and conditions.
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/ptrace.h>
-#include <asm/ptrace.h>
 #include <linux/unistd.h>
 #include "ptrace_user.h"
 #include "user_util.h"
diff -puN arch/um/kernel/tt/ptproxy/wait.c~uml-code-tidying arch/um/kernel/tt/ptproxy/wait.c
--- 25/arch/um/kernel/tt/ptproxy/wait.c~uml-code-tidying	2005-01-09 23:44:15.124864160 -0800
+++ 25-akpm/arch/um/kernel/tt/ptproxy/wait.c	2005-01-09 23:44:15.139861880 -0800
@@ -10,7 +10,6 @@ terms and conditions.
 #include <signal.h>
 #include <sys/wait.h>
 #include <sys/ptrace.h>
-#include <asm/ptrace.h>
 
 #include "ptproxy.h"
 #include "sysdep.h"
diff -puN arch/um/kernel/tt/trap_user.c~uml-code-tidying arch/um/kernel/tt/trap_user.c
--- 25/arch/um/kernel/tt/trap_user.c~uml-code-tidying	2005-01-09 23:44:15.125864008 -0800
+++ 25-akpm/arch/um/kernel/tt/trap_user.c	2005-01-09 23:44:15.140861728 -0800
@@ -6,7 +6,6 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <signal.h>
-#include <asm/sigcontext.h>
 #include "sysdep/ptrace.h"
 #include "signal_user.h"
 #include "user_util.h"
diff -puN arch/um/kernel/um_arch.c~uml-code-tidying arch/um/kernel/um_arch.c
--- 25/arch/um/kernel/um_arch.c~uml-code-tidying	2005-01-09 23:44:15.126863856 -0800
+++ 25-akpm/arch/um/kernel/um_arch.c	2005-01-09 23:44:15.140861728 -0800
@@ -17,6 +17,7 @@
 #include "linux/sysrq.h"
 #include "linux/seq_file.h"
 #include "linux/delay.h"
+#include "linux/module.h"
 #include "asm/page.h"
 #include "asm/pgtable.h"
 #include "asm/ptrace.h"
@@ -156,6 +157,8 @@ static int __init uml_version_setup(char
 {
 	printf("%s\n", system_utsname.release);
 	exit(0);
+
+	return 0;
 }
 
 __uml_setup("--version", uml_version_setup,
@@ -256,6 +259,8 @@ static int __init Usage(char *line, int 
  		p++;
  	}
 	exit(0);
+
+	return 0;
 }
 
 __uml_setup("--help", Usage,
diff -puN arch/um/os-Linux/elf_aux.c~uml-code-tidying arch/um/os-Linux/elf_aux.c
--- 25/arch/um/os-Linux/elf_aux.c~uml-code-tidying	2005-01-09 23:44:15.128863552 -0800
+++ 25-akpm/arch/um/os-Linux/elf_aux.c	2005-01-09 23:44:15.141861576 -0800
@@ -26,7 +26,6 @@ unsigned long vsyscall_end;
 
 unsigned long __kernel_vsyscall;
 
-
 __init void scan_elf_aux( char **envp)
 {
 	long page_size = 0;
diff -puN arch/um/os-Linux/Makefile~uml-code-tidying arch/um/os-Linux/Makefile
--- 25/arch/um/os-Linux/Makefile~uml-code-tidying	2005-01-09 23:44:15.129863400 -0800
+++ 25-akpm/arch/um/os-Linux/Makefile	2005-01-09 23:44:15.141861576 -0800
@@ -11,3 +11,5 @@ USER_OBJS := $(foreach file,$(USER_OBJS)
 
 $(USER_OBJS) : %.o: %.c
 	$(CC) $(CFLAGS_$(notdir $@)) $(USER_CFLAGS) -c -o $@ $<
+
+CFLAGS_user_syms.o += -DSUBARCH_$(SUBARCH)
diff -puN arch/um/os-Linux/user_syms.c~uml-code-tidying arch/um/os-Linux/user_syms.c
--- 25/arch/um/os-Linux/user_syms.c~uml-code-tidying	2005-01-09 23:44:15.130863248 -0800
+++ 25-akpm/arch/um/os-Linux/user_syms.c	2005-01-09 23:44:15.141861576 -0800
@@ -26,9 +26,6 @@ EXPORT_SYMBOL(printf);
 
 EXPORT_SYMBOL(strstr);
 
-EXPORT_SYMBOL(vsyscall_ehdr);
-EXPORT_SYMBOL(vsyscall_end);
-
 /* Here, instead, I can provide a fake prototype. Yes, someone cares: genksyms.
  * However, the modules will use the CRC defined *here*, no matter if it is
  * good; so the versions of these symbols will always match
@@ -37,6 +34,11 @@ EXPORT_SYMBOL(vsyscall_end);
        int sym(void);                  \
        EXPORT_SYMBOL(sym);
 
+#ifdef SUBARCH_i386
+EXPORT_SYMBOL(vsyscall_ehdr);
+EXPORT_SYMBOL(vsyscall_end);
+#endif
+
 EXPORT_SYMBOL_PROTO(__errno_location);
 
 EXPORT_SYMBOL_PROTO(access);
diff -puN include/asm-um/processor-i386.h~uml-code-tidying include/asm-um/processor-i386.h
--- 25/include/asm-um/processor-i386.h~uml-code-tidying	2005-01-09 23:44:15.132862944 -0800
+++ 25-akpm/include/asm-um/processor-i386.h	2005-01-09 23:44:15.142861424 -0800
@@ -24,7 +24,8 @@ struct arch_thread {
  * instruction pointer ("program counter"). Stolen
  * from asm-i386/processor.h
  */
-#define current_text_addr() ({ void *pc; __asm__("movl $1f,%0\n1:":"=g" (pc)); pc; })
+#define current_text_addr() \
+	({ void *pc; __asm__("movl $1f,%0\n1:":"=g" (pc)); pc; })
 
 #include "asm/processor-generic.h"
 
diff -puN include/asm-um/thread_info.h~uml-code-tidying include/asm-um/thread_info.h
--- 25/include/asm-um/thread_info.h~uml-code-tidying	2005-01-09 23:44:15.133862792 -0800
+++ 25-akpm/include/asm-um/thread_info.h	2005-01-09 23:44:15.142861424 -0800
@@ -47,7 +47,7 @@ static inline struct thread_info *curren
 	struct thread_info *ti;
 	unsigned long mask = PAGE_SIZE *
 		(1 << CONFIG_KERNEL_STACK_ORDER) - 1;
-	__asm__("andl %%esp,%0; ":"=r" (ti) : "0" (~mask));
+        ti = (struct thread_info *) (((unsigned long) &ti) & ~mask);
 	return ti;
 }
 
_
